@@ -157,6 +157,50 @@ void halevt_mount_check_dbus_error(DBusError *error)
   }
 }
 
+int halevt_mount_check_mount_option(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx, char *mount_option)
+{
+  DBusError dbus_error;
+  char **valid_options; 
+  char **current_option; 
+
+  if (checked_udi->udi == NULL) 
+  { 
+    fprintf (stderr, "BUG: NULL udi in halevt_mount_check_mount_option\n");
+    exit (1);
+  }
+
+  dbus_error_init(&dbus_error);
+
+  if (! libhal_device_exists(hal_ctx, checked_udi->udi, &dbus_error))
+  {
+    /* fprintf (stderr, "udi %s seems to have vanished\n", checked_udi->udi);*/
+    halevt_mount_check_dbus_error (&dbus_error);
+    return 0;
+  }
+  halevt_mount_check_dbus_error (&dbus_error);
+
+  if (! libhal_device_property_exists (hal_ctx, checked_udi->udi, "volume.mount.valid_options", &dbus_error))
+  {
+    halevt_mount_check_dbus_error (&dbus_error);
+    return 0;
+  }
+  
+  valid_options = libhal_device_get_property_strlist (hal_ctx, checked_udi->udi, "volume.mount.valid_options", &dbus_error);
+  if (valid_options == NULL)
+  {
+    halevt_mount_check_dbus_error (&dbus_error);
+    return 0;
+  }
+  halevt_mount_check_dbus_error (&dbus_error);
+  current_option = valid_options;
+  while ((*current_option) != NULL)
+  {
+    if (! strcmp ((*current_option), mount_option))
+       return 1;
+    current_option++;
+  }
+  return 0;
+}
  
 int halevt_mount_check_udi(halevt_mount_udi *checked_udi, LibHalContext *hal_ctx, int warn)
 {
@@ -1059,7 +1103,7 @@ int main (int argc, char **argv)
 
     if (mountpoint == NULL) { mountpoint = ""; }
 
-    if (! system_user)
+    if (! system_user && halevt_mount_check_mount_option(new_device_udi, hal_ctx, "uid="))
     {
        snprintf(uid_nr, 49, "%d", getuid());
        uid_nr[49] = '\0';
